pub struct RangeSlotCapacityQuery {
    pub capacity_types: Option<Vec<CapacityType>>,
    pub start_date_time: String,
    pub end_date_time: String,
}
RangeSlotCapacityQuery : Request schema for the getRangeSlotCapacity operation. This schema is used to define the time range and capacity types that are being queried.

Fields

capacity_types: Option<Vec<CapacityType>>

An array of capacity types which are being requested. Default value is [SCHEDULED_CAPACITY].

start_date_time: String

Start date time from which the capacity slots are being requested in ISO 8601 format.

end_date_time: String

End date time up to which the capacity slots are being requested in ISO 8601 format.

Implementations

Request schema for the getRangeSlotCapacity operation. This schema is used to define the time range and capacity types that are being queried.